.. _ref_session_launch_guide:

Managing sessions
=================
To use PyFluent effectively, you need to be familiar with the
functions to connect to and launch Fluent and the session objects
that those functions return. An overview is given in this section.

.. toctree::
   :maxdepth: 1
   :hidden:

   launching_ansys_fluent
   session